@@ -2,7 +2,7 @@ package Test::MobileAgent::Jphone;
 
 use strict;
 use warnings;
-use base 'Test::MobileAgent::Base';
+use base 'Test::MobileAgent::Softbank';
 
 # this list is borrowed from HTTP::MobileAgent's t/03_j_phone.t
 sub _list {q(
@@ -69,6 +69,55 @@ J-PHONE/4.0/J-T51/SNJTSA1082745 TS/1.00 Profile/MIDP-1.0 Configuration/CLDC-1.0
 J-PHONE/4.0/J-T51/SNJTSA3001961 TS/1.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0
 J-PHONE/5.0/V801SA
 J-Phone/5.0/J-SH03 (compatible; Mozilla 4.0; MSIE 5.5; YahooSeeker)
+J-PHONE/4.3/V604T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V604SH SH/0009aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V603T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V603SH SH/0007aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V602T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.2.2
+J-PHONE/4.3/V602SH SH/0006aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.2.2
+J-PHONE/4.3/V601T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.2.2
+J-PHONE/4.3/V502T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V501T TS/2.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.3/V501SH SH/0008aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.3.2
+J-PHONE/4.2/V601SH SH/0004aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.2.1
+J-PHONE/4.2/J-SH53 SH/0003aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.2.1
+J-PHONE/4.2/V601N N/01000100 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.1
+J-PHONE/4.0/J-T51 TS/1.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0
+J-PHONE/4.1/J-SH52 SH/0002aa Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.1
+J-PHONE/4.1/J-SA51 SA/0001JP Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.1
+J-PHONE/4.0/J-P51 MA/JDP51A36 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0
+J-PHONE/4.2/J-N51 N/01000100 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.1
+J-PHONE/4.0/J-K51 KW/1.00 Profile/MIDP-1.0 Configuration/CLDC-1.0 Ext-Profile/JSCL-1.1.0
+J-PHONE/3.0/V403SH
+J-PHONE/3.0/V402SH
+J-PHONE/3.0/V401T
+J-PHONE/3.0/V401SH
+J-PHONE/3.0/V401D
+J-PHONE/3.0/V302SH
+J-PHONE/3.0/V301SH
+J-PHONE/3.0/J-T08
+J-PHONE/3.0/J-T10
+J-PHONE/3.0/J-SH09
+J-PHONE/3.0/J-SH10
+J-PHONE/3.0/J-D08
+J-PHONE/3.0/J-D06
+J-PHONE/3.0/V401SA
+J-PHONE/3.0/V303T
+J-PHONE/3.0/V302T
+J-PHONE/3.0/V301T
+J-PHONE/3.0/V301D
+J-PHONE/3.0/V201SH
+J-PHONE/3.0/V102D
+J-PHONE/3.0/J-T09
+J-PHONE/3.0/J-SH04B
+J-PHONE/3.0/J-SA06
+J-PHONE/3.0/J-SA05
+J-PHONE/3.0/J-SA03
+J-PHONE/3.0/J-PE03B
+J-PHONE/3.0/J-NM01
+J-PHONE/3.0/J-D31
+J-PHONE/3.0/J-D07
+J-PHONE/3.0/V304T
 )}
 
 1;
